@@ -1,5 +1,5 @@
 #!/usr/bin/python
-# MySqlPy V1.6.0
+# MySqlPy V1.6.1
 # Author: Luca.Canali@cern.ch
 # 
 #
@@ -13,9 +13,9 @@ import sys, tempfile, optparse, unittest
 
 class mysqlpy(sqlpyPlus):
     '''
-MySqlPy V1.6.0 - 'sqlplus in python'
+MySqlPy V1.6.1 - 'sqlplus in python'
 Author: Luca.Canali@cern.ch
-Rev: 1.6.0, 02-Mar-09
+Rev: 1.6.1, 15-Mar-09
 
 Companion of SqlPython, a python module that reproduces Oracle's command line within python
 and sqlpyPlus. Major contributions by Catherine Devlin, http://catherinedevlin.blogspot.com
@@ -106,20 +106,22 @@ Do not confuse with `GET myfile.sql` and `@myfile.sql`,
 which get and run SQL scripts from disk.'''
         self.onecmd(self.query_load10g)
 
+    def do_hello(self, arg):
+        print 'Hello, World!'
+                
     def do_db(self,args,filepath='pass.txt'): 
         '''Exec do_connect to db_alias in args (credentials form the file pass.txt) '''
-        f = open(filepath,'r')
-        connectstr = f.readline().strip() +'@'+args
+        try:
+            f = open(filepath,'r')
+        except IOError:
+            print 'Need a file %s containing username/password' % filepath
+            raise
+        connectstr = f.readline().strip()
+        if args:
+            connectstr += '@'+args
         self.do_connect(connectstr)
         f.close()
 
-    def do_py(self, arg):  
-        '''Executes a python command'''
-        try:
-            exec(arg)
-        except Exception, e:
-            print e
-
     def do_tselect(self, arg):  
         '''executes a query and prints the result in trasposed form. Useful when querying tables with many columns'''  
         self.do_select(self.parsed(arg, terminator='\\t'))
@@ -140,8 +142,9 @@ which get and run SQL scripts from disk.'''
 
     def do_explain(self,args):
         '''prints the plan of a given statement from the sql cache. 1 parameter: sql_id, see also do_sql '''
-        if len(args) > 2 and args[0].lower() == 'plan' and args[1].lower() == 'for':
-            self.curs.execute('explain %s' % ' '.join(args))
+        words = args.sqlit()
+        if len(words) > 2 and words[0].lower() == 'plan' and words[1].lower() == 'for':
+            self.curs.execute('explain %s' % args)
             print 'Explained.  (see plan table)'
             return 
         self.query = "select * from table(dbms_xplan.display_cursor('"+args+"'))"
